/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * @format
 * 
 */

const Geolocation = {
  setRNConfiguration() {
    throw new Error("method not supported by the browser");
  },
  requestAuthorization() {
    throw new Error("method not supported by the browser");
  },
  async getCurrentPosition(success, error, options) {
    if (typeof success !== "function") {
      throw new Error("success callback must be a function");
    } else if (!navigator || !navigator.geolocation) {
      console.error("Navigator is undefined");
      return;
    }
    navigator.geolocation.getCurrentPosition(success, error, options);
  },
  watchPosition(success, error, options) {
    if (typeof success !== "function") {
      throw new Error("success callback must be a function");
    } else if (!navigator || !navigator.geolocation) {
      console.error("Navigator is undefined");
      return;
    }
    navigator.geolocation.watchPosition(success, error, options);
  },
  clearWatch(watchID) {
    if (!navigator || !navigator.geolocation) {
      console.error("Navigator is undefined");
      return;
    }
    navigator.geolocation.clearWatch(watchID);
  },
  stopObserving() {
    throw new Error("method not supported by the browser");
  }
};
module.exports = Geolocation;
//# sourceMappingURL=implementation.js.map